@@ -14,6 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.apache.commons.cli;
 
 import junit.framework.TestCase;
@@ -21,10 +22,18 @@ import junit.framework.TestCase;
 /**
  * @author brianegge
  */
-public class UtilTest extends TestCase {
-    public void testStripLeadingHyphens() {
+public class UtilTest extends TestCase
+{
+    public void testStripLeadingHyphens()
+    {
         assertEquals("f", Util.stripLeadingHyphens("-f"));
         assertEquals("foo", Util.stripLeadingHyphens("--foo"));
+        assertEquals("-foo", Util.stripLeadingHyphens("---foo"));
         assertNull(Util.stripLeadingHyphens(null));
     }
+
+    public void testStripLeadingAndTrailingQuotes()
+    {
+        assertEquals("foo", Util.stripLeadingAndTrailingQuotes("\"foo\""));
+    }
 }
